@@ -1,3 +1,6 @@
+from __future__ import unicode_literals
+from future.builtins import int, round
+
 from django.contrib.contenttypes.models import ContentType
 from django.db.models import Model, Count
 
