@@ -10,7 +10,8 @@ from mezzanine.conf import settings
 
 from mezzanine.core.models import CONTENT_STATUS_PUBLISHED
 from mezzanine.generic.forms import RatingForm
-from mezzanine.generic.models import AssignedKeyword, Keyword, ThreadedComment
+from mezzanine.generic.models import (AssignedKeyword, Keyword,
+                                      ThreadedComment, Rating)
 from mezzanine.pages.models import RichTextPage
 from mezzanine.utils.tests import TestCase
 
@@ -40,6 +41,28 @@ class GenericTests(TestCase):
         self.assertEqual(blog_post.rating_sum, _sum)
         self.assertEqual(blog_post.rating_average, average)
 
+    @skipUnless("mezzanine.blog" in settings.INSTALLED_APPS,
+                "blog app required")
+    def test_comment_ratings(self):
+        """
+        Test that a generic relation defined on one of Mezzanine's generic
+        models (in this case ratings of comments) correctly sets its
+        extra fields.
+        """
+        blog_post = BlogPost.objects.create(title="Post with comments",
+                                            user=self._user)
+        content_type = ContentType.objects.get_for_model(blog_post)
+        kwargs = {"content_type": content_type, "object_pk": blog_post.id,
+                  "site_id": settings.SITE_ID, "comment": "First!!!11"}
+        comment = ThreadedComment.objects.create(**kwargs)
+        comment.rating.create(value=3)
+        comment.rating.add(Rating(value=5))
+        comment = ThreadedComment.objects.get(pk=comment.pk)
+
+        self.assertEqual(len(comment.rating.all()), comment.rating_count)
+
+        self.assertEqual(comment.rating_average, 4)
+
     @skipUnless("mezzanine.blog" in settings.INSTALLED_APPS,
                 "blog app required")
     def test_comment_queries(self):
