@@ -4,10 +4,6 @@ from future.builtins import str
 from datetime import datetime, timedelta
 import re
 from time import timezone
-try:
-    from urllib.parse import quote
-except ImportError:     # Python 2
-    from urllib import quote
 
 from django.db import models
 from django.utils.encoding import python_2_unicode_compatible
@@ -60,11 +56,9 @@ class Query(models.Model):
                               "&include_rts=true" %
                               self.value.lstrip("@")),
             QUERY_TYPE_LIST: ("https://api.twitter.com/1.1/lists/statuses.json"
-                              "?list_id=%s&include_rts=true" %
-                              self.value.encode("utf-8")),
+                              "?list_id=%s&include_rts=true" % self.value),
             QUERY_TYPE_SEARCH: "https://api.twitter.com/1.1/search/tweets.json"
-                                "?q=%s" %
-                               quote(self.value.encode("utf-8")),
+                                "?q=%s" % self.value,
         }
         try:
             url = urls[self.type]
@@ -127,6 +121,10 @@ class Query(models.Model):
             d = datetime.strptime(tweet_json["created_at"], date_format)
             d -= timedelta(seconds=timezone)
             tweet.created_at = make_aware(d, get_default_timezone())
+            try:
+                tweet.save()
+            except Warning:
+                pass
             tweet.save()
         self.interested = False
         self.save()
